export class Main extends Indicator {

    constructor() {
        super();

        this.setProperty(Property.SeparateWindow, true);
        this.setProperty(Property.Minimum, -100);
        this.setProperty(Property.Maximum, 0);

        this.addLevel(-20);
        this.addLevel(-80);

        this.addInput("ExtWPRPeriod", InputType.int, 14);
        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffers = {
            ExtWPRBuffer : this.addBuffer(),
        };
    }

    onInit() {
        const  {ExtWPRPeriod} = this.getInputs();

        this.buffers.ExtWPRBuffer
            .setShape(Shape.Line)
            .setColor(Color.DodgerBlue)
            .setLabel("%R(" + ExtWPRPeriod + ")")
            .setShortName("%R(" + ExtWPRPeriod + ")")
            .setDrawBegin(ExtWPRPeriod)
        ;
    }


    async onUpdate() {
        const  {ExtWPRPeriod, PriceType} = this.getInputs(),
            {ExtWPRBuffer} = this.buffers,
            {
                High,
                Low,
                Close,
            } = await Bar.load([
                Bar.Mode.High,
                Bar.Mode.Low,
                Bar.Mode.Close,
            ], PriceType),
            barSize = Close.length;

        let i, nCountedBars = Bar.counted();

        if (barSize <= ExtWPRPeriod) return 0;

        i = barSize - ExtWPRPeriod - 1;
        if (nCountedBars > ExtWPRPeriod) {
            i = barSize - nCountedBars - 1;
        }

        while (i >= 0) {
            let dMaxHigh = High[Bar.highest(High, ExtWPRPeriod, i)];
            let dMinLow = Low[Bar.lowest(Low, ExtWPRPeriod, i)];
            ExtWPRBuffer.set(i, (-100 * (dMaxHigh - Close[i]) / (dMaxHigh - dMinLow)));
            i--;
        }
    }
}